Import of pkgsrc-2016Q3

This commit is contained in:
2016-11-18 22:39:22 +01:00
committed by sambuc
parent 9d819b6d54
commit 1242aa1e36
35952 changed files with 949747 additions and 377081 deletions
+2 -2
View File
@@ -1,7 +1,7 @@
# $NetBSD: Makefile,v 1.52 2015/06/12 10:50:52 wiz Exp $
# $NetBSD: Makefile,v 1.55 2016/07/09 06:38:45 wiz Exp $
#
DISTNAME= quagga-0.99.24.1
DISTNAME= quagga-1.0.20160315
PKGREVISION= 1
CATEGORIES= net
MASTER_SITES= http://download.savannah.gnu.org/releases/quagga/
+12 -3
View File
@@ -1,8 +1,11 @@
@comment $NetBSD: PLIST,v 1.16 2015/03/10 16:46:51 gdt Exp $
@comment $NetBSD: PLIST,v 1.17 2016/03/21 13:40:28 gdt Exp $
bin/bgp_btoa
bin/test_igmpv3_join
include/quagga/buffer.h
include/quagga/checksum.h
include/quagga/command.h
include/quagga/distribute.h
include/quagga/fifo.h
include/quagga/filter.h
include/quagga/getopt.h
include/quagga/hash.h
@@ -17,6 +20,7 @@ include/quagga/md5.h
include/quagga/memory.h
include/quagga/memtypes.h
include/quagga/network.h
include/quagga/ospfapi/ospf_apiclient.h
include/quagga/ospfd/ospf_api.h
include/quagga/ospfd/ospf_asbr.h
include/quagga/ospfd/ospf_dump.h
@@ -42,6 +46,7 @@ include/quagga/table.h
include/quagga/thread.h
include/quagga/vector.h
include/quagga/version.h
include/quagga/vrf.h
include/quagga/vty.h
include/quagga/workqueue.h
include/quagga/zassert.h
@@ -49,18 +54,22 @@ include/quagga/zclient.h
include/quagga/zebra.h
info/quagga.info
lib/libospf.la
lib/libospfapiclient.la
lib/libzebra.la
man/man1/vtysh.1
man/man8/bgpd.8
man/man8/isisd.8
man/man8/ospfclient.8
man/man8/ospfd.8
man/man8/pimd.8
man/man8/ripd.8
man/man8/watchquagga.8
man/man8/zebra.8
sbin/babeld
sbin/bgpd
sbin/isisd
sbin/ospfclient
sbin/ospfd
sbin/pimd
sbin/ripd
sbin/watchquagga
sbin/zebra
@@ -70,11 +79,11 @@ share/doc/quagga/mpls/ChangeLog.opaque.txt
share/doc/quagga/mpls/cli_summary.txt
share/doc/quagga/mpls/opaque_lsa.txt
share/doc/quagga/mpls/ospfd.conf
share/examples/quagga/babeld.conf.sample
share/examples/quagga/bgpd.conf.sample
share/examples/quagga/bgpd.conf.sample2
share/examples/quagga/isisd.conf.sample
share/examples/quagga/log_syslog.conf
share/examples/quagga/ospfd.conf.sample
share/examples/quagga/pimd.conf.sample
share/examples/quagga/ripd.conf.sample
share/examples/quagga/zebra.conf.sample
-5
View File
@@ -1,5 +0,0 @@
@comment $NetBSD: PLIST.opaquelsa,v 1.3 2012/06/07 23:38:16 gdt Exp $
include/quagga/ospfapi/ospf_apiclient.h
lib/libospfapiclient.la
man/man8/ospfclient.8
sbin/ospfclient
+7 -5
View File
@@ -1,6 +1,8 @@
$NetBSD: distinfo,v 1.23 2015/03/10 16:46:51 gdt Exp $
$NetBSD: distinfo,v 1.27 2016/06/19 23:05:51 joerg Exp $
SHA1 (quagga-0.99.24.1.tar.gz) = da5d4b1b6f524becb217355f95f99076b7a969d5
RMD160 (quagga-0.99.24.1.tar.gz) = a6b5c6d93b2d129aa4f627ae0359fa6539de6645
Size (quagga-0.99.24.1.tar.gz) = 2683800 bytes
SHA1 (patch-lib_privs.c) = d86ec56c9f57f38af6cce5285fb95759efc7c8e9
SHA1 (quagga-1.0.20160315.tar.gz) = 1d7168e2a5b33a1fd6bf89673e4c8f32c7f56ae8
RMD160 (quagga-1.0.20160315.tar.gz) = dae1a9de36482c0b6306840d375577c300a58f4d
SHA512 (quagga-1.0.20160315.tar.gz) = f17191facc4d5b0bee2d00cc3ecc4d546c6472ce5b081d79458cacca3536bd6dcea10aef480ae117f4a7f466dd88257bf2a3e37ccbe3b3b55f27ef18ead6107f
Size (quagga-1.0.20160315.tar.gz) = 2788131 bytes
SHA1 (patch-solaris_quagga.init.in) = 446f9c1efc47d54cb1af0eba47193571b63d91c0
SHA1 (patch-zebra_kernel__socket.c) = b597c299b5babc52c85e82b125ebabad66b11917
+7 -15
View File
@@ -1,6 +1,6 @@
<?xml version="1.0"?>
<!DOCTYPE service_bundle SYSTEM "/usr/share/lib/xml/dtd/service_bundle.dtd.1">
<service_bundle type='manifest' name='SUNWquagga-daemons:quagga'>
<service_bundle type='manifest' name='export'>
<service name='@SMF_PREFIX@/quagga' type='service' version='1'>
<instance name='zebra' enabled='false'>
<dependency name='fs' grouping='require_all' restart_on='none' type='service'>
@@ -29,7 +29,6 @@
</property_group>
<!-- Properties in this group are used by routeadm (1M) -->
<property_group name='routeadm' type='application'>
<stability value='Unstable' />
<!-- Identifies service as a routing service -->
<propval name='daemon' type='astring' value='@PREFIX@/sbin/zebra' />
<propval name='value_authorization' type='astring' value='solaris.smf.value.routing' />
@@ -38,7 +37,6 @@
</property_group>
<!-- Properties in this group are modifiable via routeadm (1M) -->
<property_group name='routing' type='application'>
<stability value='Evolving' />
<propval name='value_authorization' type='astring' value='solaris.smf.value.routing' />
<!-- Options common to Quagga daemons
Property names are equivalent to the long
@@ -72,7 +70,7 @@
<loctext xml:lang='C'>Quagga: zebra, RIB, kernel intermediary and misc daemon</loctext>
</common_name>
<documentation>
<manpage title='zebra' section='1M' manpath='@PREFIX@/man' />
<manpage title='zebra' section='1M' manpath='@PREFIX@/@PKGMANDIR@'/>
<doc_link name='quagga.net' uri='http://www.quagga.net/' />
</documentation>
</template>
@@ -104,7 +102,6 @@
</property_group>
<!-- Properties in this group are used by routeadm (1M) -->
<property_group name='routeadm' type='application'>
<stability value='Unstable' />
<!-- Identifies service as a routing service -->
<propval name='daemon' type='astring' value='@PREFIX@/sbin/ripd' />
<propval name='legacy-daemon' type='astring' value='/usr/sfw/sbin/ripdstart' />
@@ -144,7 +141,7 @@
<loctext xml:lang='C'>Quagga: ripd, RIPv1/2 IPv4 routing protocol daemon.</loctext>
</common_name>
<documentation>
<manpage title='ripd' section='1M' manpath='@PREFIX@/man' />
<manpage title='ripd' section='1M' manpath='@PREFIX@/@PKGMANDIR@'/>
<doc_link name='quagga.net' uri='http://www.quagga.net/' />
</documentation>
</template>
@@ -176,7 +173,6 @@
</property_group>
<!-- Properties in this group are used by routeadm (1M) -->
<property_group name='routeadm' type='application'>
<stability value='Unstable' />
<!-- Identifies service as a routing service -->
<propval name='daemon' type='astring' value='@PREFIX@/sbin/ripngd' />
<propval name='value_authorization' type='astring' value='solaris.smf.value.routing' />
@@ -215,7 +211,7 @@
<loctext xml:lang='C'>Quagga: ripngd, RIPng IPv6 routing protocol daemon.</loctext>
</common_name>
<documentation>
<manpage title='ripngd' section='1M' manpath='@PREFIX@/man' />
<manpage title='ripngd' section='1M' manpath='@PREFIX@/@PKGMANDIR@'/>
<doc_link name='quagga.net' uri='http://www.quagga.net/' />
</documentation>
</template>
@@ -250,7 +246,6 @@
</property_group>
<!-- Properties in this group are used by routeadm (1M) -->
<property_group name='routeadm' type='application'>
<stability value='Unstable' />
<!-- Identifies service as a routing service -->
<propval name='daemon' type='astring' value='@PREFIX@/sbin/ospfd' />
<propval name='legacy-daemon' type='astring' value='/usr/sfw/sbin/ospfdstart' />
@@ -288,7 +283,7 @@
<loctext xml:lang='C'>Quagga: ospfd, OSPFv2 IPv4 routing protocol daemon.</loctext>
</common_name>
<documentation>
<manpage title='ospfd' section='1M' manpath='@PREFIX@/man' />
<manpage title='ospfd' section='1M' manpath='@PREFIX@/@PKGMANDIR@'/>
<doc_link name='quagga.net' uri='http://www.quagga.net/' />
</documentation>
</template>
@@ -320,7 +315,6 @@
</property_group>
<!-- Properties in this group are used by routeadm (1M) -->
<property_group name='routeadm' type='application'>
<stability value='Unstable' />
<!-- Identifies service as a routing service -->
<propval name='daemon' type='astring' value='@PREFIX@/sbin/ospf6d' />
<propval name='value_authorization' type='astring' value='solaris.smf.value.routing' />
@@ -357,7 +351,7 @@
<loctext xml:lang='C'>Quagga: ospf6d, OSPFv3 IPv6 routing protocol daemon.</loctext>
</common_name>
<documentation>
<manpage title='ospf6d' section='1M' manpath='@PREFIX@/man' />
<manpage title='ospf6d' section='1M' manpath='@PREFIX@/@PKGMANDIR@'/>
<doc_link name='quagga.net' uri='http://www.quagga.net/' />
</documentation>
</template>
@@ -392,7 +386,6 @@
</property_group>
<!-- Properties in this group are used by routeadm (1M) -->
<property_group name='routeadm' type='application'>
<stability value='Unstable' />
<!-- Identifies service as a routing service -->
<propval name='daemon' type='astring' value='@PREFIX@/sbin/bgpd' />
<propval name='legacy-daemon' type='astring' value='/usr/sfw/sbin/bgpdstart' />
@@ -444,11 +437,10 @@
<loctext xml:lang='C'>Quagga: bgpd, BGP routing protocol daemon.</loctext>
</common_name>
<documentation>
<manpage title='bgpd' section='1M' manpath='@PREFIX@/man' />
<manpage title='bgpd' section='1M' manpath='@PREFIX@/@PKGMANDIR@'/>
<doc_link name='quagga.net' uri='http://www.quagga.net/' />
</documentation>
</template>
</instance>
<stability value='Unstable' />
</service>
</service_bundle>
+1 -13
View File
@@ -1,11 +1,9 @@
# $NetBSD: options.mk,v 1.8 2013/08/07 14:05:15 gdt Exp $
# $NetBSD: options.mk,v 1.9 2016/03/21 13:40:28 gdt Exp $
PKG_OPTIONS_VAR= PKG_OPTIONS.quagga
PKG_SUPPORTED_OPTIONS= inet6
PKG_SUPPORTED_OPTIONS+= quagga-ospf-opaque-lsa
PKG_SUPPORTED_OPTIONS+= quagga-vtysh
PKG_SUGGESTED_OPTIONS= inet6
PKG_SUGGESTED_OPTIONS+= quagga-ospf-opaque-lsa
PKG_SUGGESTED_OPTIONS+= quagga-vtysh
.include "../../mk/bsd.options.mk"
@@ -37,13 +35,3 @@ PLIST_CAT+= ${PKGDIR}/PLIST.vtysh
.else
CONFIGURE_ARGS+= --disable-vtysh
.endif
###
### Include Opaque LSA support in OSPF (RFC2370).
###
.if !empty(PKG_OPTIONS:Mquagga-ospf-opaque-lsa)
# opaque-lsa is now the upstream default.
PLIST_CAT+= ${PKGDIR}/PLIST.opaquelsa
.else
CONFIGURE_ARGS+= --disable-opaque-lsa
.endif
-162
View File
@@ -1,162 +0,0 @@
$NetBSD: patch-lib_privs.c,v 1.1 2015/01/25 22:14:05 fhajny Exp $
Fix minimum privileges setup, makes Quagga work on SunOS.
https://github.com/illumos/illumos-userland/blob/master/components/quagga/patches/75-privs-basicprivset.patch
--- solaris/quagga.init.in.orig 2015-03-07 06:58:00.000000000 +0000
+++ solaris/quagga.init.in
@@ -229,7 +229,7 @@ else
fi
fi
-upgrade_config "$DAEMON"
+#upgrade_config "$DAEMON"
if [ ! -f "@sysconfdir@/${DAEMON}.conf" ] ; then
echo "Could not find config file, @sysconfdir@/${DAEMON}.conf"
@@ -0,0 +1,24 @@
$NetBSD: patch-zebra_kernel__socket.c,v 1.1 2016/06/19 23:05:51 joerg Exp $
--- zebra/kernel_socket.c.orig 2016-06-19 18:59:02.266180373 +0000
+++ zebra/kernel_socket.c
@@ -208,7 +208,9 @@ const struct message rtm_type_str[] =
#ifdef RTM_OLDDEL
{RTM_OLDDEL, "RTM_OLDDEL"},
#endif /* RTM_OLDDEL */
+#ifdef RTM_RESOLVE
{RTM_RESOLVE, "RTM_RESOLVE"},
+#endif /* RTM_RESOLVE */
{RTM_NEWADDR, "RTM_NEWADDR"},
{RTM_DELADDR, "RTM_DELADDR"},
{RTM_IFINFO, "RTM_IFINFO"},
@@ -242,7 +244,9 @@ static const struct message rtm_flag_str
#ifdef RTF_CLONING
{RTF_CLONING, "CLONING"},
#endif /* RTF_CLONING */
+#ifdef RTF_XRESOLVE
{RTF_XRESOLVE, "XRESOLVE"},
+#endif /* RTF_XRESOLVE */
#ifdef RTF_LLINFO
{RTF_LLINFO, "LLINFO"},
#endif /* RTF_LLINFO */
--- lib/privs.c.orig 2014-08-25 16:56:53.000000000 +0000
+++ lib/privs.c
@@ -2,7 +2,7 @@
* Zebra privileges.
*
* Copyright (C) 2003 Paul Jakma.
- * Copyright (C) 2005 Sun Microsystems, Inc.
+ * Copyright (c) 2005, 2011, Oracle and/or its affiliates. All rights reserved.
*
* This file is part of GNU Zebra.
*
@@ -348,6 +348,26 @@ zprivs_caps_terminate (void)
* - http://blogs.sun.com/roller/page/gbrunett?entry=privilege_enabling_set_id_programs1
*/
+static pset_t *
+zprivs_caps_minimal ()
+{
+ pset_t *minimal;
+
+ if ((minimal = priv_str_to_set("basic", ",", NULL)) == NULL)
+ {
+ fprintf (stderr, "%s: couldn't get basic set!\n", __func__);
+ exit (1);
+ }
+
+ /* create a minimal privilege set from the basic set */
+ (void) priv_delset(minimal, PRIV_PROC_EXEC);
+ (void) priv_delset(minimal, PRIV_PROC_INFO);
+ (void) priv_delset(minimal, PRIV_PROC_SESSION);
+ (void) priv_delset(minimal, PRIV_FILE_LINK_ANY);
+
+ return minimal;
+}
+
/* convert zebras privileges to system capabilities */
static pset_t *
zcaps2sys (zebra_capabilities_t *zcaps, int num)
@@ -376,26 +396,34 @@ zcaps2sys (zebra_capabilities_t *zcaps,
int
zprivs_change_caps (zebra_privs_ops_t op)
{
+ pset_t *privset;
/* should be no possibility of being called without valid caps */
assert (zprivs_state.syscaps_p);
if (!zprivs_state.syscaps_p)
{
+ fprintf (stderr, "%s: Eek, missing privileged caps!", __func__);
+ exit (1);
+ }
+
+ assert (zprivs_state.caps);
+ if (!zprivs_state.caps)
+ {
fprintf (stderr, "%s: Eek, missing caps!", __func__);
exit (1);
}
-
- /* to raise: copy original permitted into our working effective set
- * to lower: just clear the working effective set
+
+ /* to raise: copy original permitted as our working effective set
+ * to lower: copy regular effective set stored in zprivs_state.caps
*/
if (op == ZPRIVS_RAISE)
- priv_copyset (zprivs_state.syscaps_p, zprivs_state.caps);
+ privset = zprivs_state.syscaps_p;
else if (op == ZPRIVS_LOWER)
- priv_emptyset (zprivs_state.caps);
+ privset = zprivs_state.caps;
else
return -1;
- if (setppriv (PRIV_SET, PRIV_EFFECTIVE, zprivs_state.caps) != 0)
+ if (setppriv (PRIV_SET, PRIV_EFFECTIVE, privset) != 0)
return -1;
return 0;
@@ -423,15 +451,15 @@ zprivs_state_caps (void)
}
else
{
- if (priv_isemptyset (effective) == B_TRUE)
+ if (priv_isequalset (effective, zprivs_state.syscaps_p))
+ result = ZPRIVS_RAISED;
+ else if (priv_isequalset (effective, zprivs_state.caps))
result = ZPRIVS_LOWERED;
else
- result = ZPRIVS_RAISED;
+ result = ZPRIVS_UNKNOWN;
}
- if (effective)
- priv_freeset (effective);
-
+ priv_freeset (effective);
return result;
}
@@ -439,7 +467,7 @@ static void
zprivs_caps_init (struct zebra_privs_t *zprivs)
{
pset_t *basic;
- pset_t *empty;
+ pset_t *minimal;
/* the specified sets */
zprivs_state.syscaps_p = zcaps2sys (zprivs->caps_p, zprivs->cap_num_p);
@@ -467,14 +495,6 @@ zprivs_caps_init (struct zebra_privs_t *
priv_union (basic, zprivs_state.syscaps_p);
priv_freeset (basic);
- /* we need an empty set for 'effective', potentially for inheritable too */
- if ( (empty = priv_allocset()) == NULL)
- {
- fprintf (stderr, "%s: couldn't get empty set!\n", __func__);
- exit (1);
- }
- priv_emptyset (empty);
-
/* Hey kernel, we know about privileges!
* this isn't strictly required, use of setppriv should have same effect
*/
@@ -517,16 +537,19 @@ zprivs_caps_init (struct zebra_privs_t *
exit (1);
}
- /* now clear the effective set and we're ready to go */
- if (setppriv (PRIV_SET, PRIV_EFFECTIVE, empty))
+ /* we need a minimal basic set for 'effective', potentially for inheritable too */
+ minimal = zprivs_caps_minimal();
+
+ /* now set the effective set with a subset of basic privileges */
+ if (setppriv (PRIV_SET, PRIV_EFFECTIVE, minimal))
{
fprintf (stderr, "%s: error setting effective set!, %s\n", __func__,
safe_strerror (errno) );
exit (1);
}
- /* we'll use this as our working-storage privset */
- zprivs_state.caps = empty;
+ /* we'll use the minimal set as our working-storage privset */
+ zprivs_state.caps = minimal;
/* set methods for the caller to use */
zprivs->change = zprivs_change_caps;
@@ -538,8 +561,7 @@ zprivs_caps_terminate (void)
{
assert (zprivs_state.caps);
- /* clear all capabilities */
- priv_emptyset (zprivs_state.caps);
+ /* clear all capabilities by using working-storage privset */
setppriv (PRIV_SET, PRIV_EFFECTIVE, zprivs_state.caps);
setppriv (PRIV_SET, PRIV_PERMITTED, zprivs_state.caps);
setppriv (PRIV_SET, PRIV_INHERITABLE, zprivs_state.caps);
@@ -0,0 +1,15 @@
$NetBSD: patch-solaris_quagga.init.in,v 1.3 2016/01/27 13:48:01 jperkin Exp $
Disable the broken upgrade function, unsuitable and unnecessary for pkgsrc.